@@ -157,12 +157,11 @@ variablesArgumentLISREL <- function(model, manifestVars, latentVars, submodels,
 		}
 	} else {
 		if (length(manifestVars) + length(latentVars) > 0) {
-			if(length(names(latentVars)) == 0 || !is.list(latentVars) ){
-				stop("Unlike RAM, LISREL models must have latent variables.  The latentVars argument of a LISREL model must be a named list.")
-			}
-			if(length(names(manifestVars)) == 0 || !is.list(manifestVars) ){
-				stop("The manifestVars argument of a LISREL model must be a named list.")
+			if(length(latentVars) == 0) {
+				stop("Unlike RAM, LISREL models must have latent variables.")
 			}
+      if (!is.list(latentVars)) latentVars <- list(endo=latentVars)
+			if (length(manifestVars) && !is.list(manifestVars)) manifestVars <- list(endo=manifestVars)
 			latentVars <- varsToCharacter(latentVars, "latent")
 			manifestVars <- varsToCharacter(manifestVars, "manifest")
 			checkVariables(model, latentVars, manifestVars)
@@ -173,7 +172,6 @@ variablesArgumentLISREL <- function(model, manifestVars, latentVars, submodels,
 		}
 	}
 	return(model)
-	# include check prior to varsToCharacter to see if length(names(latentVars)) == 0 (and if same for manifestVars
 }
 
 removeVariablesLISREL <- function(model, latent, manifest){
@@ -531,11 +529,14 @@ insertLatentEndoPathsLISREL <- function(from, to, arrows, old, new, variables){
 #manifestExo -> 'one'
 #	stop('nonsense')
 
+manifestToLatentError <- function(from, to) {
+  stop(paste('In LISREL, paths are not allowed from manifest variables to latent variables;',
+             'from=',omxQuotes(from), 'to=', omxQuotes(to)))
+}
+
 insertManifestExoPathsLISREL <- function(from, to, arrows, old, new, variables){
-	if(to %in% variables$lex){
-		stop('In LISREL, paths are not allowed from manifest variables to latent variables.')
-	} else if(to %in% variables$len){
-		stop('In LISREL, paths are not allowed from manifest variables to latent variables.')
+	if(to %in% variables$lex || to %in% variables$len){
+    manifestToLatentError(from, to)
 	} else if(to %in% variables$mex){
 		if(arrows==1){
 			stop('In LISREL, one-headed arrows are not allowed between manifest exogenous variables.')
@@ -574,10 +575,8 @@ insertManifestExoPathsLISREL <- function(from, to, arrows, old, new, variables){
 #	stop('nonsense')
 
 insertManifestEndoPathsLISREL <- function(from, to, arrows, old, new, variables){
-	if(to %in% variables$lex){
-		stop('In LISREL, paths are not allowed from manifest variables to latent variables.')
-	} else if(to %in% variables$len){
-		stop('In LISREL, paths are not allowed from manifest variables to latent variables.')
+	if(to %in% variables$lex || to %in% variables$len){
+    manifestToLatentError(from, to)
 	} else if(to %in% variables$mex){
 		if(arrows==1){
 			stop('In LISREL, one-headed arrows are not allowed between manifest exogenous variables.')
