@@ -313,24 +313,24 @@ void omxRAMExpectation::init() {
 
 	ProtectedSEXP Rbetween(R_do_slot(rObj, Rf_install("between")));
 	if (Rf_length(Rbetween)) {
-		if (!oo->data) stop("%s: data is required for joins", oo->name);
-		if (!Rf_isInteger(Rbetween)) stop("%s: between must be an integer vector", oo->name);
+		if (!oo->data) mxThrow("%s: data is required for joins", oo->name);
+		if (!Rf_isInteger(Rbetween)) mxThrow("%s: between must be an integer vector", oo->name);
 		RAMexp->between.reserve(Rf_length(Rbetween));
 		int *bnumber = INTEGER(Rbetween);
 		for (int jx=0; jx < Rf_length(Rbetween); ++jx) {
 			omxMatrix *bmat = currentState->getMatrixFromIndex(bnumber[jx]);
 			int foreignKey = bmat->getJoinKey();
 			omxExpectation *fex = bmat->getJoinModel();
-			if (!fex) stop("%s: level transition matrix '%s' does not reference the upper level model",
+			if (!fex) mxThrow("%s: level transition matrix '%s' does not reference the upper level model",
 					   oo->name, bmat->name());
 			omxCompleteExpectation(fex);
 			if (!strEQ(fex->name, "MxExpectationRAM")) {
-				stop("%s: only MxExpectationRAM can be joined with MxExpectationRAM (not %s)",
+				mxThrow("%s: only MxExpectationRAM can be joined with MxExpectationRAM (not %s)",
 								oo->name, fex->name);
 			}
 			omxDataKeysCompatible(fex->data, oo->data, foreignKey);
 			if (!omxDataColumnIsKey(oo->data, foreignKey)) {
-				stop("Cannot join using non-integer type column '%s' in '%s'. "
+				mxThrow("Cannot join using non-integer type column '%s' in '%s'. "
 					 "Did you forget to use mxData(..., sort=FALSE)?",
 					 omxDataColumnName(oo->data, foreignKey),
 					 oo->data->name);
@@ -349,7 +349,7 @@ void omxRAMExpectation::init() {
 	k = RAMexp->A->cols;
 
 	if (k != RAMexp->S->cols || k != RAMexp->S->rows || k != RAMexp->A->rows) {
-		stop("RAM matrices '%s' and '%s' must have the same dimensions",
+		mxThrow("RAM matrices '%s' and '%s' must have the same dimensions",
 			 RAMexp->S->name(), RAMexp->A->name());
 	}
 
@@ -359,7 +359,7 @@ void omxRAMExpectation::init() {
 		ProtectedSEXP RprodNode(R_do_slot(rObj, Rf_install("isProductNode")));
 		if (Rf_length(RprodNode)) {
 			if (Rf_length(RprodNode) != A->cols) {
-				stop("isProductNode must be same dimension as A matrix");
+				mxThrow("isProductNode must be same dimension as A matrix");
 			}
 			for (int px = 0; px < A->cols; ++px) {
 				if (INTEGER(RprodNode)[px]) {
@@ -439,7 +439,7 @@ void omxRAMExpectation::studyExoPred()
 				else latentName = S->colnames[cx];
 			}
 			if (!toManifest && !latentName) continue;
-			if (latentName) stop("%s: latent exogenous variables are not supported (%s -> %s)", name,
+			if (latentName) mxThrow("%s: latent exogenous variables are not supported (%s -> %s)", name,
 						 S->colnames[dv.col], latentName);
 			exoDataCol[dv.col] = dv.column;
 			found += 1;
@@ -688,7 +688,7 @@ namespace RelationalRAMExpectation {
 				RowToLayoutMapType::const_iterator it =
 					rowToLayoutMap.find(std::make_pair(e1->data, row));
 				if (it == rowToLayoutMap.end())
-					stop("Cannot find row %d in %s", row, e1->data->name);
+					mxThrow("Cannot find row %d in %s", row, e1->data->name);
 				int bx = it->second;
 				cc.connect(ax, bx);
 			}
@@ -876,7 +876,7 @@ namespace RelationalRAMExpectation {
 			// insert_or_assign would be nice here
 			RowToLayoutMapType::const_iterator it = rowToLayoutMap.find(std::make_pair(data, frow));
 			if (it != rowToLayoutMap.end()) {
-				if (it->second < 0) stop("%s cycle detected: '%s' row %d joins against itself",
+				if (it->second < 0) mxThrow("%s cycle detected: '%s' row %d joins against itself",
 							     homeEx->name, data->name, 1+frow);
 				return it->second;
 			}
@@ -1113,7 +1113,7 @@ namespace RelationalRAMExpectation {
 			state::RowToLayoutMapType::const_iterator it =
 				st.rowToLayoutMap.find(std::make_pair(e1->data, row));
 			if (it == st.rowToLayoutMap.end())
-				stop("Cannot find row %d in %s", row, e1->data->name);
+				mxThrow("Cannot find row %d in %s", row, e1->data->name);
 			return &st.layout[it->second];
 		}
 
@@ -1297,7 +1297,7 @@ namespace RelationalRAMExpectation {
 		for (auto it : allEx) {
 			omxRAMExpectation *ram = (omxRAMExpectation*) it;
 			if (ram->getThresholdInfo().size()) {
-				stop("%s: Ordinal indicators are not supported in multilevel models", ram->name);
+				mxThrow("%s: Ordinal indicators are not supported in multilevel models", ram->name);
 			}
 			omxData *data = ram->data;
 			int numDefVars = data->defVars.size();
@@ -1462,7 +1462,7 @@ namespace RelationalRAMExpectation {
 	void independentGroup::place(int ax)
 	{
 		if (st.layout[ax].ig) {
-			stop("Unit[%d] already assigned; this is a bug", ax);
+			mxThrow("Unit[%d] already assigned; this is a bug", ax);
 		}
 		st.layout[ax].ig = this;
 		int mx = 0;
@@ -1589,7 +1589,7 @@ namespace RelationalRAMExpectation {
 					dx += 1;
 				}
 				if (a1.numObs() != dx - prevDx) {
-					stop("numObs() %d != %d", a1.numObs(), dx - prevDx);
+					mxThrow("numObs() %d != %d", a1.numObs(), dx - prevDx);
 				}
 			}
 			for (int vx=0; vx < ram->F->cols; ++vx) {
@@ -1637,7 +1637,7 @@ namespace RelationalRAMExpectation {
 			for (size_t tx=0; tx < t1.size(); ++tx) {
 				addrSetup &a1 = layoutSetup[ t1[tx] ];
 				if (specimen.clump.size() != a1.clump.size()) {
-					stop("BUG: clump size mismatch; alert developers");
+					mxThrow("BUG: clump size mismatch; alert developers");
 				}
 				t2.push_back(a1.clump[cx]);
 			}
@@ -1701,7 +1701,7 @@ namespace RelationalRAMExpectation {
 				std::vector<int> dc(a1.clump);
 				std::sort(dc.begin(), dc.end(), RampartClumpCompare(this));
 				for (size_t cx=0; cx < dc.size(); ++cx) {
-					if (dc[cx] != a1.clump[cx]) stop("oops");
+					if (dc[cx] != a1.clump[cx]) mxThrow("oops");
 				}
 			}
 		}
@@ -1872,11 +1872,11 @@ namespace RelationalRAMExpectation {
 			omxRAMExpectation *ram1 = (omxRAMExpectation*) ex;
 			hasProductNodes |= ram1->getHasProductNodes();
 			if (!ex->data->hasWeight() && !ex->data->hasFreq()) continue;
-			stop("%s: row frequencies or weights provided in '%s' are not compatible with joins",
+			mxThrow("%s: row frequencies or weights provided in '%s' are not compatible with joins",
 				 expectation->name, ex->data->name);
 		}
 		if (hasProductNodes && getOptimizeMean() < 2) {
-			stop("%s: .optimizeMean=2L is required for product nodes", homeEx->name);
+			mxThrow("%s: .optimizeMean=2L is required for product nodes", homeEx->name);
 		}
 
 		Eigen::VectorXd paramSave;
@@ -2204,7 +2204,7 @@ namespace RelationalRAMExpectation {
 				omxData *data1 = betA->getJoinModel()->data;
 				int frow = data1->lookupRowOfKey(key);
 				int a2Offset = pst.rowToLayoutMap[std::make_pair(data1, frow)];
-				if (ax < a2Offset) stop("Not in topological order");
+				if (ax < a2Offset) mxThrow("Not in topological order");
 				addr &a2 = pst.layout[a2Offset];
 				independentGroup &tig2 = *group[a2.ig->arrayIndex];
 				omxRecompute(betA, fc);
